==> haskell-lsp-test-0.14.0.1-175-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lsp-test
version:              0.14.0.1
visibility:           public
id:                   lsp-test-0.14.0.1-DLu4rUge1SN7cADONYO52I
key:                  lsp-test-0.14.0.1-DLu4rUge1SN7cADONYO52I
license:              BSD-3-Clause
copyright:            2021 Luke Lau
maintainer:           luke_lau@icloud.com
author:               Luke Lau
homepage:
    https://github.com/haskell/lsp/blob/master/lsp-test/README.md

synopsis:             Functional test framework for LSP servers.
description:
    A test framework for writing tests against
    <https://microsoft.github.io/language-server-protocol/ Language Server Protocol servers>.
    @Language.LSP.Test@ launches your server as a subprocess and allows you to simulate a session
    down to the wire.
    To see examples of it in action, check out <https://github.com/haskell/haskell-ide-engine haskell-ide-engine>,
    <https://github.com/haskell/haskell-language-server haskell-language-server> and
    <https://github.com/digital-asset/ghcide ghcide>.

category:             Testing
abi:                  13ba5958342ebb60cf9b343429febe5d
exposed:              True
exposed-modules:
    Control.Applicative.Combinators from parser-combinators-1.3.0-FL5bcA6sX4a2ejs4tDtkjB:Control.Applicative.Combinators,
    Language.LSP.Test,
    Language.LSP.Types from lsp-types-1.3.0.1-4igjOVQIWgbC2xrxJBrX44:Language.LSP.Types,
    Language.LSP.Types.Capabilities from lsp-types-1.3.0.1-4igjOVQIWgbC2xrxJBrX44:Language.LSP.Types.Capabilities

hidden-modules:
    Language.LSP.Test.Compat Language.LSP.Test.Decoding
    Language.LSP.Test.Exceptions Language.LSP.Test.Files
    Language.LSP.Test.Parsing Language.LSP.Test.Server
    Language.LSP.Test.Session

import-dirs:          /usr/lib/ghc-9.0.2/site-local/lsp-test-0.14.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/lsp-test-0.14.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-test
hs-libraries:         HSlsp-test-0.14.0.1-DLu4rUge1SN7cADONYO52I
depends:
    Diff-0.4.1-14FzpHO7DvM9ZrKSnS0Jaa
    Glob-0.10.2-3ooHigPL8A468fcpRmnG7T
    aeson-2.1.1.0-K9BW85jPsWRAK2RMwS3bY2
    aeson-pretty-0.8.9-L7FfK2U9gTw5NS8lPexlWs
    ansi-terminal-0.11.4-4SgCWaXZr2qIqjtLzwrNoa
    async-2.2.4-DsKZe3TE8bS5FmfUvwss6n base-4.15.1.0
    bytestring-0.10.12.1 conduit-1.3.4.3-7850AKAUO1kCI5lKyzLnW1
    conduit-parse-0.2.1.1-2F5aiU1k3ScBRcxGYYt4pk containers-0.6.4.1
    data-default-0.7.1.1-BkZarJ3J3008hHF2JOuYeW directory-1.3.6.2
    filepath-1.4.2.1 lens-5.2-HshKI406bdO6VQU9Db7XBS
    lsp-types-1.3.0.1-4igjOVQIWgbC2xrxJBrX44 mtl-2.2.2
    parser-combinators-1.3.0-FL5bcA6sX4a2ejs4tDtkjB process-1.6.13.2
    some-1.0.4.1-3oTC5bddeLcpEd54xiVBi text-1.2.5.0 time-1.9.3
    transformers-0.5.6.2 unix-2.7.2.2
    unordered-containers-0.2.19.1-GtFja3NZ1tw4exmhm99dqw

haddock-interfaces:   /usr/share/doc/haskell-lsp-test/html/lsp-test.haddock
haddock-html:         /usr/share/doc/haskell-lsp-test/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lsp-test-0.14.0.2-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lsp-test
version:              0.14.0.2
visibility:           public
id:                   lsp-test-0.14.0.2-GW8iLAYnFV6G1znp2wglZ
key:                  lsp-test-0.14.0.2-GW8iLAYnFV6G1znp2wglZ
license:              BSD-3-Clause
copyright:            2021 Luke Lau
maintainer:           luke_lau@icloud.com
author:               Luke Lau
homepage:
    https://github.com/haskell/lsp/blob/master/lsp-test/README.md

synopsis:             Functional test framework for LSP servers.
description:
    A test framework for writing tests against
    <https://microsoft.github.io/language-server-protocol/ Language Server Protocol servers>.
    @Language.LSP.Test@ launches your server as a subprocess and allows you to simulate a session
    down to the wire.
    To see examples of it in action, check out <https://github.com/haskell/haskell-ide-engine haskell-ide-engine>,
    <https://github.com/haskell/haskell-language-server haskell-language-server> and
    <https://github.com/digital-asset/ghcide ghcide>.

category:             Testing
abi:                  736725ff91c018e8c8ed71251865beda
exposed:              True
exposed-modules:
    Control.Applicative.Combinators from parser-combinators-1.3.0-FL5bcA6sX4a2ejs4tDtkjB:Control.Applicative.Combinators,
    Language.LSP.Test,
    Language.LSP.Types from lsp-types-1.4.0.1-7ShjpHJkxmk27ZGEfLRsPn:Language.LSP.Types,
    Language.LSP.Types.Capabilities from lsp-types-1.4.0.1-7ShjpHJkxmk27ZGEfLRsPn:Language.LSP.Types.Capabilities

hidden-modules:
    Language.LSP.Test.Compat Language.LSP.Test.Decoding
    Language.LSP.Test.Exceptions Language.LSP.Test.Files
    Language.LSP.Test.Parsing Language.LSP.Test.Server
    Language.LSP.Test.Session

import-dirs:          /usr/lib/ghc-9.0.2/site-local/lsp-test-0.14.0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/lsp-test-0.14.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-test
hs-libraries:         HSlsp-test-0.14.0.2-GW8iLAYnFV6G1znp2wglZ
depends:
    Diff-0.4.1-DQewZc8J6zuFxtdL8SNOKp
    Glob-0.10.2-KOLQS0coC5A6YlxLhI3G2b
    aeson-2.1.1.0-8KPen6hyeogLmhemp4ZbOa
    aeson-pretty-0.8.9-HgDgW0QkNCrJG86cGxB5yu
    ansi-terminal-0.11.4-4SgCWaXZr2qIqjtLzwrNoa
    async-2.2.4-GElwEr766DP3ejURF9fDgA base-4.15.1.0
    bytestring-0.10.12.1 conduit-1.3.4.3-DqMUcg2g6IHJPWkqDo26v
    conduit-parse-0.2.1.1-KObn66O3uOZFliwnxTamM containers-0.6.4.1
    data-default-0.7.1.1-BkZarJ3J3008hHF2JOuYeW directory-1.3.6.2
    filepath-1.4.2.1 lens-5.2-FIFCk99mBlr59mek6Z6LQh
    lsp-types-1.4.0.1-7ShjpHJkxmk27ZGEfLRsPn mtl-2.2.2
    parser-combinators-1.3.0-FL5bcA6sX4a2ejs4tDtkjB process-1.6.13.2
    some-1.0.4.1-3oTC5bddeLcpEd54xiVBi text-1.2.5.0 time-1.9.3
    transformers-0.5.6.2 unix-2.7.2.2
    unordered-containers-0.2.19.1-AupS6pw9cGS61feF3nE08

haddock-interfaces:   /usr/share/doc/haskell-lsp-test/html/lsp-test.haddock
haddock-html:         /usr/share/doc/haskell-lsp-test/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
